@@ -26,6 +26,8 @@
 #include <config.h>
 #endif /* HAVE_CONFIG_H */
 
+#include <stdint.h>
+
 #include <glib.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -40,14 +42,14 @@
 
 
 /* method prototypes */
-  // file selection handling
+  /* file selection handling */
 static void cria_open_presentation_from_filename (char const *filename);
 
-  // GObject used methods
+  /* GObject used methods */
 static void cria_application_init (CriaApplication* self);
 
-//int x = -1, y, w = -1, h = -1;
-//char *debug_modules = NULL;
+/*int x = -1, y, w = -1, h = -1;*/
+/*char *debug_modules = NULL;	*/
 
 gboolean	start_off = 0,
 		debug     = 0;
@@ -57,11 +59,11 @@ static const struct poptOption options[] = {
 	{"start-off", 's', POPT_ARG_NONE, &start_off, 0,
 		N_("Start a presentation (and open a file selection if no file "
 			"is given at the command line)"), NULL},
-//	{NULL, 'x', POPT_ARG_INT, &x, 0, N_("X position of window"), N_("X")},
-//	{NULL, 'y', POPT_ARG_INT, &y, 0, N_("Y position of window"), N_("Y")},
-//	{NULL, 'w', POPT_ARG_INT, &w, 0, N_("width of window"), N_("WIDTH")},
-//	{NULL, 'h', POPT_ARG_INT, &h, 0, N_("height of window"), N_("WIDTH")},
-/*	{"debug-modules", '\0', POPT_ARG_STRING, &debug_modules, 0,
+/*	{NULL, 'x', POPT_ARG_INT, &x, 0, N_("X position of window"), N_("X")},
+	{NULL, 'y', POPT_ARG_INT, &y, 0, N_("Y position of window"), N_("Y")},
+	{NULL, 'w', POPT_ARG_INT, &w, 0, N_("width of window"), N_("WIDTH")},
+	{NULL, 'h', POPT_ARG_INT, &h, 0, N_("height of window"), N_("WIDTH")},
+	{"debug-modules", '\0', POPT_ARG_STRING, &debug_modules, 0,
 		N_("Modules to enable debugging in"), N_("MODULES")},
 */	{NULL, '\0', 0, NULL, 0}
 };
@@ -89,24 +91,28 @@ static	void	  cria_application_set_property(GObject		* object,
 						guint		  prop_id,
 						const	GValue	* value,
 						GParamSpec	* param_spec);
-#if 0
-/* enable this to add support for signals */
-static	guint	cria_application_signals[N_SIGNALS] = { 0 };
-
-static	void	cria_application_signal	       (CriaApplication	* template,
-						const	gchar	* string);
-#endif
 
+/**
+ * criawips_init:
+ * @argc: pointer to argc as delivered to the main() method
+ * @argv: pointer to the argument vector as delivered to the main() method
+ *
+ * Initializes the application. #criawips_init parses the command line arguments
+ * and strips those arguments it understood from argc and argv.
+ */
 void
 criawips_init(int *argc, char ***argv) {
+#warning "criawips_init(): FIXME: check for a runnning instance, delegate command line tasks to it"
 	const gchar	**filenames;
 	GnomeProgram	* gnome_program;
 	GValue		* value;
 	poptContext	  popt_context;
+	GError		* error = NULL;
 
 	g_set_prgname (PACKAGE);
 	g_debug("criawips_init(): start");
 
+	/* initialize i18n */
 #ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -117,10 +123,18 @@ criawips_init(int *argc, char ***argv) {
 	  /* GTK+ */
 	gtk_init (argc, argv);
 
+	gtk_window_set_default_icon_from_file(PACKAGE_DATA_DIR "/pixmaps/criawips.png", &error);
+	if (error) {
+		gchar	* message = g_strdup_printf(_("Couldn't set window icon, you have to live without; reason: %s"), error->message);
+		cria_application_show_error_dialog(NULL, _("Error"), message);
+		g_error_free (error);
+		g_free(message);
+	}
+
 	  /* libgnome(ui) */
 	gnome_program = gnome_program_init (
 			PACKAGE, PACKAGE_VERSION,
-			LIBGNOMEUI_MODULE, // module info
+			LIBGNOMEUI_MODULE,
 			*argc, *argv,
 			GNOME_PARAM_POPT_TABLE, options,
 			GNOME_PARAM_POPT_FLAGS, 0,
@@ -151,7 +165,21 @@ criawips_init(int *argc, char ***argv) {
 		
 		if (filenames && filenames[0]) {
 			if (filenames[1]) {
-				// open a warning dialog that says that we're only displaying the first file
+				GtkWidget* dialog = gtk_message_dialog_new_with_markup(NULL,
+									  	      0,
+									  	      GTK_MESSAGE_WARNING,
+									  	      GTK_BUTTONS_CLOSE,
+									   	      "<span weight=\"bold\">%s</span>\n\n%s",
+									   	      _("Criawips can only show one presentation"),
+										      _("You tried to show more than one presentation. Criawips cannot handle this yet."));
+				gtk_widget_show(dialog);
+				gtk_dialog_run(GTK_DIALOG(dialog));
+				gtk_widget_hide(dialog);
+
+				while(gtk_events_pending()) {
+					gtk_main_iteration();
+				}
+				gtk_object_destroy(GTK_OBJECT(dialog));
 			}
 			
 			cria_open_presentation_from_filename (filenames[0]);
@@ -194,9 +222,9 @@ criawips_init(int *argc, char ***argv) {
 		} else {
 			/* open each file in a new window */
 			const gchar	**iterator;
-			g_debug("criawips_init(): filenames is a char** at 0x%x", (int)filenames);
+			g_debug("criawips_init(): filenames is a char** at 0x%x", (uintptr_t)filenames);
 			for (iterator = filenames; iterator && *iterator; iterator++) {
-				g_debug("criawips_init(): iterator is now 0x%x >> 0x%x (%s)", (int)iterator, (int)(*iterator), *iterator);
+				g_debug("criawips_init(): iterator is now 0x%x >> 0x%x (%s)", (uintptr_t)iterator, (uintptr_t)(*iterator), *iterator);
 				cria_main_window_new(*iterator);
 			}
 		}
@@ -205,9 +233,15 @@ criawips_init(int *argc, char ***argv) {
 	g_debug("criawips_init(): end");
 }
 
+/**
+ * criawips_quit:
+ *
+ * Quit Criawips, close all application windows and then exit the application.
+ */
 void
 criawips_quit (void) {
-	// get the application object and quit all window instances
+#warning "criawips_quit(): FIXME: Ask open windows to save their content"
+	/* get the application object and quit all window instances */
 	if (gtk_main_level() > 0) {
 		gtk_main_quit ();
 	} else {
@@ -255,7 +289,7 @@ cria_open_presentation_from_filename (const gchar* filename) {
 	}
 }
 
-//----------------------------------------------------------------------------
+/*---------------------------------------------------------------------------*/
 
 static void
 cria_application_class_init (CriaApplicationClass* cria_application_class) {
@@ -284,6 +318,13 @@ cria_application_class_init (CriaApplicationClass* cria_application_class) {
 	g_object_class->get_property = cria_application_get_property;
 }
 
+/**
+ * cria_application_register_window:
+ * @window:
+ *
+ * Registers a #CriaMainWindow to the application. Thus it's being propted to
+ * close the file before quitting.
+ */
 void
 cria_application_register_window(CriaMainWindow	* window) {
 	CriaApplication	* self;
@@ -299,11 +340,16 @@ cria_application_register_window(CriaMainWindow	* window) {
 			self->priv->windows,
 			g_object_ref(window));
 
-	//g_object_notify(self, "windows");
+	/*g_object_notify(self, "windows");*/
 
 	g_debug("cria_application_register_window(): end");
 }
 
+/**
+ * cria_application_get_instance:
+ *
+ * Return value: the instance of the application
+ */
 CriaApplication*
 cria_application_get_instance (void) {
 	if (!instance) {
@@ -367,6 +413,15 @@ cria_application_set_property (
 	}
 }
 
+/**
+ * cria_application_show_error_dialog:
+ * @parent:
+ * @title:
+ * @message:
+ *
+ * Shows an error dialog. To be used when fatal things happen (e.g. loading the
+ * ui definitions from the glade file failed)
+ */
 void
 cria_application_show_error_dialog (GtkWindow* parent, gchar const* title, gchar const* message) {
 	GtkWidget	* dialog,
@@ -385,7 +440,7 @@ cria_application_show_error_dialog (GtkWindow* parent, gchar const* title, gchar
 			     NULL);
 	gtk_widget_show(label);
 
-	gtk_container_add(GTK_DIALOG(dialog)->vbox,
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),
 			  label);
 	gtk_widget_show_all(dialog);
 	
