@@ -58,11 +58,6 @@ struct _CriaApplication {
 
 struct _CriaApplicationClass {
 	GObjectClass		  base_class;
-#if 0
-	/* signals */
-	void (*signal)	       (CriaApplication	* template,
-				const	gchar	* string);
-#endif
 };
 
 G_END_DECLS
