@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* this file is part of criawips a gnome presentation application
  *
  * AUTHORS
@@ -23,6 +22,7 @@
  */
 
 #include <string.h>
+#include <stdint.h>
 
 #include <glib-object.h>
 #include <glib.h>
@@ -63,12 +63,12 @@ static	void	cria_layout_block_set_property (GObject		* object,
 						guint		  prop_id,
 						const	GValue	* value,
 						GParamSpec	* param_spec);
-
+#if 0
 static	guint	cria_layout_block_signals[N_SIGNALS] = { 0 };
 
 static	void	cria_layout_block_signal       (CriaLayoutBlock	* template,
 						const	gchar	* string);
-
+#endif
 static void
 cria_layout_block_class_init (CriaLayoutBlockClass* cria_layout_block_class) {
 	GObjectClass	* g_object_class;
@@ -95,174 +95,121 @@ cria_layout_block_class_init (CriaLayoutBlockClass* cria_layout_block_class) {
 	g_object_class->set_property = cria_layout_block_set_property;
 	g_object_class->get_property = cria_layout_block_get_property;
 
-	g_object_class_install_property (
-			g_object_class,
-			PROP_TITLE,
-			g_param_spec_string (
-				"title",
-				"Title",
-				"The Title of this block, used to connect slide blocks to their layouts",
-				_("untitled"),
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_POS_X,
-			g_param_spec_double (
-				"pos-x",
-				"X-Position",
-				"The Position of the topleft corner of the layout box",
-				-G_MAXDOUBLE,
-				G_MAXDOUBLE,
-				0,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_POS_X_UNIT,
-			g_param_spec_enum (
-				"pos-x-unit",
-				"X-Position unit",
-				"The unit for the x position value in \"pos-x\".",
-				CRIA_TYPE_UNIT,
-				CRIA_UNIT_PIXEL,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_POS_Y,
-			g_param_spec_double (
-				"pos-y",
-				"Y-Position",
-				// TODO add documentation
-				"",
-				-G_MAXDOUBLE,
-				G_MAXDOUBLE,
-				0,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_POS_Y_UNIT,
-			g_param_spec_enum (
-				"pos-y-unit",
-				"X-Position",
-				// TODO add documentation
-				"",
-				CRIA_TYPE_UNIT,
-				CRIA_UNIT_PIXEL,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_WIDTH,
-			g_param_spec_double (
-				"width",
-				"Width",
-				// TODO add documentation
-				"",
-				-G_MAXDOUBLE,
-				G_MAXDOUBLE,
-				0,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_WIDTH_UNIT,
-			g_param_spec_enum (
-				"width-unit",
-				"X-Position",
-				// TODO add documentation
-				"",
-				CRIA_TYPE_UNIT,
-				CRIA_UNIT_PIXEL,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_HEIGHT,
-			g_param_spec_double (
-				"height",
-				"Height",
-				// TODO add documentation
-				"",
-				-G_MAXDOUBLE,
-				G_MAXDOUBLE,
-				0.,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_HEIGHT_UNIT,
-			g_param_spec_enum (
-				"height-unit",
-				"X-Position",
-				// TODO add documentation
-				"",
-				CRIA_TYPE_UNIT,
-				CRIA_UNIT_PIXEL,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_ALIGNMENT,
-			g_param_spec_enum (
-				"alignment",
-				"Horizontal Alignment",
-				// TODO add documentation
-				"",
-				CRIA_TYPE_ALIGNMENT,
-				CRIA_ALIGNMENT_LEFT,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_VALIGNMENT,
-			g_param_spec_enum (
-				"valignment",
-				"Vertical Alignment",
-				// TODO add documentation
-				"",
-				CRIA_TYPE_VALIGNMENT,
-				CRIA_ALIGNMENT_TOP,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_DEFAULT_TEXT,
-			g_param_spec_string (
-				"default-text",
-				"Default Text",
-				// TODO add documentation
-				"",
-				_("this block has no content"),
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_FONT_FAMILY,
-			g_param_spec_string (
-				"family",
-				"Font Family",
-				// TODO add documentation
-				"",
-				"Sans",
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_FONT_SIZE,
-			g_param_spec_double (
-				"size",
-				"Font Size",
-				// TODO add documentation
-				"",
-				-G_MINDOUBLE,
-				G_MAXDOUBLE,
-				// TODO add some configurable default size
-				0.,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
+	g_object_class_install_property(g_object_class,
+					PROP_TITLE,
+					g_param_spec_string("title",
+							    "Title",
+							    "The Title of this block, used to connect slide blocks to their layouts",
+							    _("untitled"),
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_POS_X,
+					g_param_spec_double("pos-x",
+							    "X-Position",
+							    "The Position of the topleft corner of the layout box",
+							    -G_MAXDOUBLE,
+							    G_MAXDOUBLE,
+							    0.0,
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_POS_X_UNIT,
+					g_param_spec_enum("pos-x-unit",
+							  "X-Position unit",
+							  "The unit for the x position value in \"pos-x\".",
+							  CRIA_TYPE_UNIT,
+							  CRIA_UNIT_PIXEL,
+							  G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_POS_Y,
+					g_param_spec_double("pos-y",
+							    "Y-Position",
+							    "The vertical position of the block",
+							    -G_MAXDOUBLE,
+							    G_MAXDOUBLE,
+							    0.0,
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_POS_Y_UNIT,
+					g_param_spec_enum("pos-y-unit",
+							  "Y-Position unit",
+							  "The unit of the vertical position of the block",
+							  CRIA_TYPE_UNIT,
+							  CRIA_UNIT_PIXEL,
+							  G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_WIDTH,
+					g_param_spec_double("width",
+							    "Width",
+							    "The width of the block",
+							    -G_MAXDOUBLE,
+							    G_MAXDOUBLE,
+							    0.0,
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_WIDTH_UNIT,
+					g_param_spec_enum("width-unit",
+							  "Width Unit",
+							  "The unit of the width of the block",
+							  CRIA_TYPE_UNIT,
+							  CRIA_UNIT_PIXEL,
+							  G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_HEIGHT,
+					g_param_spec_double("height",
+							    "Height",
+							    "The height of the block",
+							    -G_MAXDOUBLE,
+							    G_MAXDOUBLE,
+							    0.0,
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_HEIGHT_UNIT,
+					g_param_spec_enum("height-unit",
+							  "Height Unit",
+							  "The unit of the height of the block",
+							  CRIA_TYPE_UNIT,
+							  CRIA_UNIT_PIXEL,
+							  G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_ALIGNMENT,
+					g_param_spec_enum("alignment",
+							  "Horizontal Alignment",
+							  "The text alignment of this block",
+							  CRIA_TYPE_ALIGNMENT,
+							  CRIA_ALIGNMENT_LEFT,
+							  G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_VALIGNMENT,
+					g_param_spec_enum("valignment",
+							  "Vertical Alignment",
+							  "The vertical alignment of the block",
+							  CRIA_TYPE_VALIGNMENT,
+							  CRIA_ALIGNMENT_TOP,
+							  G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_DEFAULT_TEXT,
+					g_param_spec_string("default-text",
+							    "Default Text",
+							    "The default text of this block",
+							    _("this block has no content"),
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_FONT_FAMILY,
+					g_param_spec_string("family",
+							    "Font Family",
+							    "The font family used to render the text",
+							    "Sans",
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_FONT_SIZE,
+					g_param_spec_double("size",
+							    "Font Size",
+							    "The size of the font for rendering this block",
+							    -G_MINDOUBLE,
+							    G_MAXDOUBLE,
+#warning "FIXME add some configurable default size"
+							    0.0,
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
 CriaAlignment
@@ -286,7 +233,7 @@ cria_layout_block_get_default_text (CriaLayoutBlock *self)
 const char *
 cria_layout_block_get_font_family (CriaLayoutBlock * self)
 {
-	// TODO return the default value
+#warning "FIXME return the default value"
 	g_return_val_if_fail (CRIA_IS_LAYOUT_BLOCK (self), NULL);
 
 	return self->font_family;
@@ -295,7 +242,7 @@ cria_layout_block_get_font_family (CriaLayoutBlock * self)
 gdouble
 cria_layout_block_get_font_size (CriaLayoutBlock * self)
 {
-	// TODO return the default value
+#warning "FIXME return the default value"
 	g_return_val_if_fail (CRIA_IS_LAYOUT_BLOCK (self), 0);
 
 	g_debug ("cria_layout_block_get_font_size(): got %f", self->font_size);
@@ -483,20 +430,17 @@ cria_layout_block_set_alignment (
 }
 
 void
-cria_layout_block_set_default_text (
-		CriaLayoutBlock * self,
-		char const	* text)
-{
-	g_return_if_fail (CRIA_IS_LAYOUT_BLOCK (self));
+cria_layout_block_set_default_text (CriaLayoutBlock* self, gchar const* text) {
+	g_return_if_fail(CRIA_IS_LAYOUT_BLOCK (self));
+	g_debug("cria_layout_block_set_default_text(): new default text \"%s\".", text);
 	
-	if (self->default_text)
-		g_free (self->default_text);
+	if(self->default_text) {
+		g_free(self->default_text);
+	}
 
-	self->default_text = g_strdup (text);
+	self->default_text = g_strdup(text);
 
-	g_object_notify (
-			G_OBJECT (self),
-			"default-text");
+	g_object_notify(G_OBJECT(self), "default-text");
 }
 
 void
@@ -730,7 +674,7 @@ cria_layout_block_set_title (
 
 	self->title = g_strdup (title);
 
-	g_debug ("cria_layout_block_set_title(): title 0x%x", (guint) self->title);
+	g_debug ("cria_layout_block_set_title(): title 0x%x", (uintptr_t)(self->title));
 	g_object_notify (G_OBJECT (self), "title");
 }
 
@@ -848,7 +792,6 @@ cria_unit_val_from_string (char const * string)
 CriaVAlignment
 cria_valignment_from_string (char const * string)
 {
-#warning implement stub method
+#warning "implement stub method"
 	return CRIA_ALIGNMENT_TOP;
 }
-
