@@ -26,6 +26,7 @@
 
 #include "libglade-support.h"
 #include "slide-list.h"
+#include "slide-view.h"
 
 GtkWidget*
 criawips_libglade_custom_handler (GladeXML* xml, gchar* func_name, gchar* widget_name, gchar* string1, gchar* string2, gint int1, gint int2, gpointer data) {
@@ -33,6 +34,8 @@ criawips_libglade_custom_handler (GladeXML* xml, gchar* func_name, gchar* widget
 
 	if (strcmp(widget_name, "main_slide_list") == 0) {
 		return_widget = cria_slide_list_new();
+	} else if(strcmp(widget_name, "main_slide_view") == 0) {
+		return_widget = cria_slide_view_new();
 	} else {
 		g_assert_not_reached();
 		return NULL;
