@@ -27,6 +27,7 @@
 #endif
 
 #include <string.h>
+#include <stdint.h>
 
 #include <glib.h>
 #include <glib-object.h>
@@ -73,12 +74,13 @@ static	void	cria_main_window_set_property  (GObject		* object,
 						GParamSpec	* param_spec);
 static void	  cria_main_window_set_zoom_from_spin  (CriaMainWindow  * template,
 							GtkSpinButton	* spinner);
+static	void	cria_main_window_start_off	       (CriaMainWindow	* self);
+#if 0
 static	void	cria_main_window_signal		       (CriaMainWindow	* template,
 							const	gchar	* string);
-static	void	cria_main_window_start_off	       (CriaMainWindow	* self);
 
 static	guint	cria_main_window_signals[N_SIGNALS] = { 0 };
-
+#endif
 static void
 cria_main_window_class_init (CriaMainWindowClass	* cria_main_window_class)
 {
@@ -106,63 +108,52 @@ cria_main_window_class_init (CriaMainWindowClass	* cria_main_window_class)
 	g_object_class->set_property = cria_main_window_set_property;
 	g_object_class->get_property = cria_main_window_get_property;
 
-	g_object_class_install_property (
-			g_object_class,
-			PROP_PRESENTATION,
-			g_param_spec_object (
-				"presentation",
-				"Presentation",
-				"This is the presentation that's currently assotiated with this main window",
-				CRIA_TYPE_PRESENTATION,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
+	g_object_class_install_property(g_object_class,
+					PROP_PRESENTATION,
+					g_param_spec_object("presentation",
+							    "Presentation",
+							    "This is the presentation that's currently assotiated with this main window",
+							    CRIA_TYPE_PRESENTATION,
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
-CriaMainWindow*
-cria_main_window_new(const gchar* filename) {
-	CriaMainWindow	* self;
-
-	g_debug("cria_main_window_new(): start");
+/*
+ * cria_main_window_displayed_slide_changed:
+ * @self: ...
+ * @slide_view: ...
+ *
+ * ...
+ */
+static void
+cria_main_window_displayed_slide_changed(CriaMainWindow* self, CriaSlideView* slide_view) {
+	gchar	* message;
 	
-	self = g_object_new(CRIA_TYPE_MAIN_WINDOW, NULL);
-	
-	if (filename != NULL) {
-		CriaPresentation	* p;
-		GError			* error = NULL;
+	g_assert(self != NULL && CRIA_IS_MAIN_WINDOW(self));
+	g_assert(slide_view != NULL && CRIA_IS_SLIDE_VIEW(slide_view));
+	g_assert(self->priv != NULL);
+	g_assert(self->priv->xml != NULL && GLADE_IS_XML(self->priv->xml));
+	g_assert(!self->priv->presentation || CRIA_IS_PRESENTATION(self->priv->presentation));
 
-		g_debug("cria_main_window_new(): got filename 0x%x(\"%s\")", (int)filename, filename);
-		
-		p = cria_presentation_new_from_file(filename, &error);
-
-		if (error) {
-			/* NOTE: keep these strings in sync with the ones from application.c */
-			char            * error_message = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s %s:\n<span style=\"italic\">%s</span>.",
-									  _("The Presentation could not be opened"),
-									  _("For some reason the presentation you wanted to open could not be opened."),
-									  _("The reason was:"),
-									  error->message);
-			cria_application_show_error_dialog(GTK_WINDOW(glade_xml_get_widget(self->priv->xml, "main_window")),
-					 		   _("Error opening file"),
-							   error_message);
-			g_free(error_message);
-			g_error_free(error);
-		} else {
-			g_debug ("cria_main_window_new(): setting presentation");
-		
-			g_object_set(G_OBJECT(self), "presentation", p, NULL);
-
-			g_debug ("cria_main_window_new(): done");
-		}
+	if(!self->priv->presentation) {
+		message = _("No Presentation assigned");
+	} else if(cria_presentation_n_slides(self->priv->presentation) < 1) {
+		message = _("The Presentation doesn't contains any slides");
+	} else if(!cria_slide_view_get_slide(slide_view)) {
+		message = _("No Slide selected");
+	} else if(cria_presentation_get_slide_index(self->priv->presentation, cria_slide_view_get_slide(slide_view)) >= 0) {
+		message = g_strdup_printf("<span weight=\"bold\">%s %d/%d \"%s\"</span>",
+					  _("Slide"),
+					  cria_presentation_get_slide_index(self->priv->presentation, cria_slide_view_get_slide(slide_view)) + 1,
+					  cria_presentation_n_slides(self->priv->presentation),
+					  cria_slide_get_title(cria_slide_view_get_slide(slide_view)));
 	} else {
-		g_debug("cria_main_window_new(): filename was NULL, we're done");
+		/* the slide could not be found in the presentation */
+		g_assert_not_reached();
 	}
-	
-	g_debug("cria_main_window_new(): in between");
-	
-	cria_application_register_window(self);
 
-	g_debug("cria_main_window_new(): end");
-	return self;
+	gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(self->priv->xml, "main_label_displayed_title")), message);
+
+	g_free(message);
 }
 
 CriaPresentation*
@@ -236,7 +227,6 @@ cria_main_window_init(CriaMainWindow* self) {
 	
 	/* creating the private data */
 	self->priv = g_new0(CriaMainWindowPriv,1);
-	// FIXME add some nice warning if this fails
 	self->priv->xml = glade_xml_new(PACKAGE_DATA_DIR "/" PACKAGE "/data/criawips.glade", NULL, NULL);
 
 	if (!self->priv->xml) {
@@ -262,56 +252,31 @@ cria_main_window_init(CriaMainWindow* self) {
 			G_CALLBACK(criawips_quit),
 			NULL);
 	  /* menus */
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_file_new"),
-			FALSE);
-	g_signal_connect_swapped(glade_xml_get_widget(self->priv->xml, "main_menu_file_open"),
-			"activate",
-			G_CALLBACK(cria_main_window_open),
-			self);
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_file_save"),
-			FALSE);
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_file_save_as"),
-			FALSE);
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_file_properties"),
-			FALSE);
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_file_close"),
-			FALSE);
-	g_signal_connect(glade_xml_get_widget(self->priv->xml, "main_menu_file_quit"),
-			"activate",
-			G_CALLBACK(criawips_quit),
-			NULL);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_file_new"), FALSE);
+	g_signal_connect_swapped(glade_xml_get_widget(self->priv->xml, "main_menu_file_open"), "activate",
+				 G_CALLBACK(cria_main_window_open), self);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_file_save"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_file_save_as"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_file_properties"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_file_close"), FALSE);
+	g_signal_connect(glade_xml_get_widget(self->priv->xml, "main_menu_file_quit"), "activate",
+			 G_CALLBACK(criawips_quit), NULL);
 
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_edit_cut"),
-			FALSE);
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_edit_copy"),
-			FALSE);
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_edit_paste"),
-			FALSE);
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_edit_clear"),
-			FALSE);
-	gtk_widget_set_sensitive(
-			glade_xml_get_widget(self->priv->xml, "main_menu_edit_preferences"),
-			FALSE);
-	
-	g_signal_connect_swapped(glade_xml_get_widget(self->priv->xml, "main_menu_view_start_off"),
-			"activate",
-			G_CALLBACK(cria_main_window_start_off),
-			self);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_edit_cut"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_edit_copy"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_edit_paste"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_edit_clear"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_edit_preferences"), FALSE);
 
-	g_signal_connect_swapped(
-			glade_xml_get_widget(self->priv->xml, "main_menu_help_about"),
-			"activate",
-			G_CALLBACK(cria_main_window_show_about),
-			self);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_zoom_in"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_zoom_out"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_view_zoom_100"), FALSE);
+	gtk_widget_set_sensitive(glade_xml_get_widget(self->priv->xml, "main_menu_view_zoom_fit"), FALSE);
+	g_signal_connect_swapped(glade_xml_get_widget(self->priv->xml, "main_menu_view_start_off"), "activate",
+				 G_CALLBACK(cria_main_window_start_off), self);
+
+	g_signal_connect_swapped(glade_xml_get_widget(self->priv->xml, "main_menu_help_about"), "activate",
+				 G_CALLBACK(cria_main_window_show_about), self);
 	  /* toolbars */
 	g_signal_connect_swapped(
 			glade_xml_get_widget(self->priv->xml, "main_tool_button_open"),
@@ -332,11 +297,12 @@ cria_main_window_init(CriaMainWindow* self) {
 			self);
 
 	/* slide list */
-	g_signal_connect_swapped(
-			gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(self->priv->xml, "main_slide_list"))),
-			"changed",
-			G_CALLBACK(cria_main_window_selected_slide_changed),
-			self);
+	g_signal_connect_swapped(gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(self->priv->xml, "main_slide_list"))), "changed",
+				 G_CALLBACK(cria_main_window_selected_slide_changed), self);
+
+	/* slide view */
+	g_signal_connect_swapped(glade_xml_get_widget(self->priv->xml, "main_slide_view"), "slide-changed",
+				 G_CALLBACK(cria_main_window_displayed_slide_changed), self);
 
 	/* display the window */
 	gtk_widget_show(glade_xml_get_widget(self->priv->xml, "main_window"));
@@ -344,32 +310,90 @@ cria_main_window_init(CriaMainWindow* self) {
 	g_debug("cria_main_window_init(): end");
 }
 
+/**
+ * cria_main_window_new:
+ * @filename: filename of the new window
+ *
+ * Creates a new main window displaying the presentation that @filename
+ * points to. It automatically registers the window for the application
+ * to make it managed by the application. @filename can be NULL to create
+ * a window without a presentation.
+ *
+ * Returns a new main window
+ */
+CriaMainWindow*
+cria_main_window_new(const gchar* filename) {
+	CriaMainWindow	* self;
+
+	g_debug("cria_main_window_new(): start");
+	
+	self = g_object_new(CRIA_TYPE_MAIN_WINDOW, NULL);
+	
+	if (filename != NULL) {
+		CriaPresentation	* p;
+		GError			* error = NULL;
+
+		g_debug("cria_main_window_new(): got filename 0x%x(\"%s\")", (uintptr_t)filename, filename);
+		
+		p = cria_presentation_new_from_file(filename, &error);
+
+		if (error) {
+			/* NOTE: keep these strings in sync with the ones from application.c */
+			char            * error_message = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s %s:\n<span style=\"italic\">%s</span>.",
+									  _("The Presentation could not be opened"),
+									  _("For some reason the presentation you wanted to open could not be opened."),
+									  _("The reason was:"),
+									  error->message);
+			cria_application_show_error_dialog(GTK_WINDOW(glade_xml_get_widget(self->priv->xml, "main_window")),
+					 		   _("Error opening file"),
+							   error_message);
+			g_free(error_message);
+			g_error_free(error);
+		} else {
+			g_debug ("cria_main_window_new(): setting presentation");
+		
+			g_object_set(G_OBJECT(self), "presentation", p, NULL);
+
+			g_debug ("cria_main_window_new(): done");
+		}
+	} else {
+		g_debug("cria_main_window_new(): filename was NULL, we're done");
+	}
+	
+	g_debug("cria_main_window_new(): in between");
+	
+	cria_application_register_window(self);
+
+	g_debug("cria_main_window_new(): end");
+	return self;
+}
+
 static void
 cria_main_window_open(CriaMainWindow* self, gpointer d) {
-	// FIXME implement code for opening more than one file at a moment
-	GtkWidget	* dialog = gtk_file_chooser_dialog_new (
-			"Open File",
-			NULL,
-			GTK_FILE_CHOOSER_ACTION_OPEN,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-			NULL);
+	GtkWidget	* dialog = gtk_file_chooser_dialog_new("Open File",
+							       NULL,
+							       GTK_FILE_CHOOSER_ACTION_OPEN,
+							       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+							       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+							       NULL);
+	gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dialog), TRUE);
 
-	if (gtk_dialog_run(GTK_DIALOG(dialog))) {
+	if(gtk_dialog_run(GTK_DIALOG(dialog))) {
 		gtk_widget_hide(dialog);
 
-		while (gtk_events_pending()) {
+		while(gtk_events_pending()) {
 			gtk_main_iteration();
 		}
 		
 		GSList			* uris	   = gtk_file_chooser_get_uris(GTK_FILE_CHOOSER(dialog));
+		/*g_object_unref(dialog); dialog = NULL;*/
 
-		if (uris && g_slist_length(uris) == 1) {
+		if(uris && g_slist_length(uris) == 1) {
 			GError	* error = NULL;
 			
 			cria_main_window_set_presentation(self, cria_presentation_new_from_uri((gchar*)uris->data, &error));
 
-			if (error) {
+			if(error) {
 				/* NOTE: keep the string in sync with the ones from application.c */
 				char            * error_message = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s %s:\n<span style=\"italic\">%s</span>.",
 										  _("The Presentation could not be opened"),
@@ -385,7 +409,29 @@ cria_main_window_open(CriaMainWindow* self, gpointer d) {
 				g_error_free(error);
 			}
 		} else {
-			// FIXME implement code for opening more than one file at a moment
+			GSList	* it = NULL;
+			GError	* error = NULL;
+			for(it = uris; it; it = it->next) {
+				CriaMainWindow*	mainwin = cria_main_window_new(NULL);
+				cria_main_window_set_presentation(mainwin, cria_presentation_new_from_uri((gchar*)it->data, &error));
+				gtk_widget_show(GTK_WIDGET(glade_xml_get_widget(mainwin->priv->xml, "main_window")));
+
+				if(error) {
+					/* NOTE: keep the string in sync with the ones from application.c */
+					char            * error_message = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s %s:\n<span style=\"italic\">%s</span>.",
+											  _("The Presentation could not be opened"),
+											  _("For some reason the presentation you wanted to open could not be opened."),
+											  _("The reason was:"),
+											  error->message);
+					cria_application_show_error_dialog(GTK_WINDOW(glade_xml_get_widget(mainwin->priv->xml, "main_window")),
+							_("Error opening file"),
+							error_message);
+					gtk_dialog_run(GTK_DIALOG(dialog));
+					
+					g_free(error_message);
+					g_error_free(error);
+				}
+			}
 		}
 	}
 
