@@ -31,8 +31,8 @@
 
 G_BEGIN_DECLS
 
-CriaPresentation* cria_presentation_parser_get_new_presentation(GsfInput* input,
-								GError	**error); 
+CriaPresentation* cria_presentation_parse_input_xml    (GsfInput        * input,
+							GError		**error);
 
 G_END_DECLS
 
