@@ -55,12 +55,12 @@ static	void	cria_slide_block_set_property        (GObject		* object,
 						guint		  prop_id,
 						const	GValue	* value,
 						GParamSpec	* param_spec);
-
+#if 0
 static	guint	cria_slide_block_signals[N_SIGNALS] = { 0 };
 
 static	void	cria_slide_block_signal	       (CriaSlideBlock	* template,
 						const	gchar	* string);
-
+#endif
 static void
 cria_slide_block_class_init (CriaSlideBlockClass	* cria_slide_block_class)
 {
@@ -88,17 +88,13 @@ cria_slide_block_class_init (CriaSlideBlockClass	* cria_slide_block_class)
 	g_object_class->set_property = cria_slide_block_set_property;
 	g_object_class->get_property = cria_slide_block_get_property;
 
-	g_object_class_install_property (
-			g_object_class,
-			PROP_TITLE,
-			g_param_spec_string (
-				"title",
-				"Title",
-				// TODO add documentation
-				"",
-				"default_value",
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
+	g_object_class_install_property(g_object_class,
+					PROP_TITLE,
+					g_param_spec_string("title",
+							    "Title",
+							    "The name of this block",
+							    "default_value",
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
 const gchar*
