@@ -27,6 +27,7 @@
 #endif /* HAVE_CONFIG_H */
 
 #include <math.h>
+#include <stdint.h>
 
 #include <glib-object.h>
 #include <glib.h>
@@ -74,12 +75,12 @@ static	void	cria_slide_show_set_property   (GObject		* object,
 						guint		  prop_id,
 						const	GValue	* value,
 						GParamSpec	* param_spec);
-
+#if 0
 static	guint	cria_slide_show_signals[N_SIGNALS] = { 0 };
 
 static	void	cria_slide_show_signal	       (CriaSlideShow	* template,
 						const	gchar	* string);
-
+#endif
 enum {
 	KEYS_NONE,
 	KEYS_FORWARD,
@@ -101,8 +102,8 @@ cria_key_press_event_cb (
 
 	slide = cria_slide_show_get_slide (CRIA_SLIDE_SHOW (widget));
 
-	// TODO If we want to make it configurable we have to use a
-	// method instead of a switch statement
+	/* TODO If we want to make it configurable we have to use a
+	 * method instead of a switch statement */
 	switch (event->keyval) {
 	case GDK_space:
 	case GDK_Right:
@@ -164,26 +165,23 @@ cria_slide_show_class_init (CriaSlideShowClass	* cria_slide_show_class) {
 
 	g_object_class = G_OBJECT_CLASS(cria_slide_show_class);
 
-	// TODO make this reflect the expected behavior
-	cria_slide_show_class->screen_width = gdk_screen_get_width (gdk_screen_get_default ());
-	cria_slide_show_class->screen_height= gdk_screen_get_height (gdk_screen_get_default ());
-
 	/* setting up signal system */
-//	cria_slide_show_class->signal = cria_slide_show_signal;
-
-//	cria_slide_show_signals[SIGNAL] = g_signal_new (
-//			"signal",
-//			CRIA_TYPE_SLIDE_SHOW,
-//			G_SIGNAL_RUN_LAST,
-//			G_STRUCT_OFFSET (
-//				CriaSlideShowClass,
-//				signal),
-//			NULL,
-//			NULL,
-//			g_cclosure_marshal_VOID__STRING,
-//			G_TYPE_NONE,
-//			0);
+#if 0
+	cria_slide_show_class->signal = cria_slide_show_signal;
 
+	cria_slide_show_signals[SIGNAL] = g_signal_new (
+			"signal",
+			CRIA_TYPE_SLIDE_SHOW,
+			G_SIGNAL_RUN_LAST,
+			G_STRUCT_OFFSET (
+				CriaSlideShowClass,
+				signal),
+			NULL,
+			NULL,
+			g_cclosure_marshal_VOID__STRING,
+			G_TYPE_NONE,
+			0);
+#endif
 	/* setting up property system */
 	g_object_class->set_property = cria_slide_show_set_property;
 	g_object_class->get_property = cria_slide_show_get_property;
@@ -350,8 +348,12 @@ cria_slide_show_init (CriaSlideShow *self)
 			self->priv->canvas,
 			GTK_STATE_NORMAL,
 			color);
-	gnome_canvas_set_pixels_per_unit(GNOME_CANVAS (self->priv->canvas), 1.0);
-	gnome_canvas_set_scroll_region (GNOME_CANVAS (self->priv->canvas), 0, 0, CRIA_SLIDE_SHOW_GET_CLASS(self)->screen_width, CRIA_SLIDE_SHOW_GET_CLASS(self)->screen_height);
+	gnome_canvas_set_pixels_per_unit(GNOME_CANVAS(self->priv->canvas), 1.0);
+	gnome_canvas_set_scroll_region(GNOME_CANVAS(self->priv->canvas),
+				       0,
+				       0,
+				       cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
+				       cria_slide_get_display_height(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()));
 
 	/* setting up gestures */
 	self->priv->gesture_handler = gtk_gesture_handler_new (GTK_WIDGET (self->priv->canvas));
@@ -363,17 +365,6 @@ cria_slide_show_init (CriaSlideShow *self)
 			GTK_GESTURE_FUNC (cria_slide_show_prev_page_event),
 			self, NULL);
 	
-	/* setting up the window */
-	gtk_window_set_default_icon_from_file (
-			PACKAGE_DATA_DIR "/pixmaps/criawips.png",
-			&error);
-	if (error) {
-		gchar	* message = g_strdup_printf(_("Couldn't set window icon, you have to live without; reason: %s"), error->message);
-		cria_application_show_error_dialog(NULL, _("Error"), message);
-		g_error_free (error);
-		g_free(message);
-	}
-
 	gtk_window_fullscreen (GTK_WINDOW (self));
 	gtk_container_add (
 			GTK_CONTAINER (self),
@@ -447,8 +438,7 @@ cria_slide_show_prev_page_event (
 }
 
 static void
-cria_slide_show_render_after_show (CriaSlideShow *self)
-{
+cria_slide_show_render_after_show (CriaSlideShow *self) {
 	gchar		* title;
 	GnomeCanvasItem	* rectangle,
 			* text;
@@ -459,16 +449,14 @@ cria_slide_show_render_after_show (CriaSlideShow *self)
 	cria_slide_show_clear (self);
 	
 	/* black slide */
-	rectangle = gnome_canvas_item_new (
-			self->priv->group,
-			GNOME_TYPE_CANVAS_RECT,
-			"x1", 0.,
-			"y1", 0.,
-			// TODO update this to reflect slide instead of screen size
-			"x2", (gdouble) CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
-			"y2", (gdouble) CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
-			"fill-color", "black",
-			NULL);
+	rectangle = gnome_canvas_item_new (self->priv->group,
+					   GNOME_TYPE_CANVAS_RECT,
+					   "fill-color", "black",
+					   "x1", 0.0,
+					   "y1", 0.0,
+					   "x2", 0.0 + cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
+					   "y2", 0.0 + cria_slide_get_display_height(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
+					   NULL);
 	gnome_canvas_item_show (rectangle);
 	
 	/* message */
@@ -478,9 +466,8 @@ cria_slide_show_render_after_show (CriaSlideShow *self)
 			"anchor", GTK_ANCHOR_CENTER,
 			"text", _("press a key or click to close this window..."),
 			"fill-color", "white",
-			// TODO update this to reflect slide instead of screen size
-			"x", (gdouble) (CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width / 2),
-			"y", (gdouble) (CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height / 2),
+			"x", (gdouble) (cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()) / 2),
+			"y", (gdouble) (cria_slide_get_display_height(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()) / 2),
 			NULL);
 	gnome_canvas_item_show (text);
 
@@ -490,8 +477,7 @@ cria_slide_show_render_after_show (CriaSlideShow *self)
 			title);
 	g_free (title);
 
-	// TODO set key and mouse handler
-	
+	/* TODO set key and mouse handler */
 	g_debug ("cria_slide_show_render_after_show(%i): end", __LINE__);
 	return;
 }
@@ -512,9 +498,8 @@ cria_slide_show_render_slide (CriaSlideShow *self) {
 	slide		= cria_presentation_get_slide (presentation, self->slide);
 	theme 		= cria_slide_get_theme (slide);
 	layout		= cria_slide_get_layout (slide);
-	// hmmm... these long lines make me want to write this in java
 
-	g_debug ("cria_slide_show_render_slide(): theme=0x%x layout=0x%x", (guint)theme, (guint)layout);
+	g_debug ("cria_slide_show_render_slide(): theme=0x%x layout=0x%x", (uintptr_t)theme, (uintptr_t)layout);
 	
 	if (theme && layout) {
 		char	**blocks,
@@ -528,14 +513,11 @@ cria_slide_show_render_slide (CriaSlideShow *self) {
 				gnome_canvas_pixbuf_get_type (),
 				"x", (gdouble) 0.,
 				"y", (gdouble) 0.,
-				// TODO update this to reflect slide size instead of screen size
-				"height", (gdouble) CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
-				"height-in-pixels", TRUE,
+				"height", cria_slide_get_display_height(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
 				"height-set", TRUE,
-				// TODO store image in layout and get it from there
+				/* TODO store image in layout and get it from there */
 				"pixbuf", cria_layout_get_background (layout),
-				"width", (gdouble) CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
-				"width-in-pixels", TRUE,
+				"width", cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
 				"width-set", TRUE,
 				NULL);
 		
@@ -551,43 +533,36 @@ cria_slide_show_render_slide (CriaSlideShow *self) {
 			CriaAlignment	  alignment = cria_layout_block_get_alignment (cria_layout_get_block (layout, *iterator));
 			GtkJustification  gtk_align = GTK_JUSTIFY_LEFT;
 			GtkAnchorType	  gtk_anchor= GTK_ANCHOR_NORTH_WEST;
-			gdouble		  xpos  = cria_layout_block_get_pos_x (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
-					  ypos  = cria_layout_block_get_pos_y (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
-					  width = cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
-					  height= cria_layout_block_get_height(cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
+			gdouble		  xpos  = cria_layout_block_get_pos_x (cria_layout_get_block (layout, *iterator)) / 100 * cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
+					  ypos  = cria_layout_block_get_pos_y (cria_layout_get_block (layout, *iterator)) / 100 * cria_slide_get_display_height(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
+					  width = cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
 					  font_size = cria_layout_block_get_font_size (cria_layout_get_block (layout, *iterator));
 
 			font_size = (font_size <= 0)?1:font_size;
 
-			if (alignment == CRIA_ALIGNMENT_LEFT)
-			{
+			if (alignment == CRIA_ALIGNMENT_LEFT) {
 				g_debug ("cria_slide_show_render_slide(%s:%i): left rendering:", __FILE__, __LINE__);
 				xpos = xpos;
 				ypos = ypos;
 				gtk_anchor= GTK_ANCHOR_NORTH_WEST;
 				gtk_align = GTK_JUSTIFY_LEFT;
-			}
-			else if (alignment == CRIA_ALIGNMENT_CENTER)
-			{
+			} else if (alignment == CRIA_ALIGNMENT_CENTER) {
 				g_debug ("cria_slide_show_render_slide(%s:%i): centered rendering:", __FILE__, __LINE__);
 				xpos = xpos + (0.5 * width);
 				ypos = ypos;
 				gtk_anchor= GTK_ANCHOR_NORTH;
 				gtk_align = GTK_JUSTIFY_CENTER;
-			}
-			else if (alignment == CRIA_ALIGNMENT_RIGHT)
-			{
+			} else if (alignment == CRIA_ALIGNMENT_RIGHT) {
 				g_debug ("cria_slide_show_render_slide(%s:%i): right rendering:", __FILE__, __LINE__);
 				xpos = xpos + width;
 				ypos = ypos;
 				gtk_anchor= GTK_ANCHOR_NORTH_EAST;
 				gtk_align = GTK_JUSTIFY_RIGHT;
-			}
-			else
+			} else {
 				g_debug ("cria_slide_show_render_slide(%s:%i): unknown alignment value", __FILE__, __LINE__);
+			}
 			
-			if (cria_slide_get_block (slide, *iterator))
-			{
+			if (cria_slide_get_block (slide, *iterator)) {
 				/* 2.2.a - render slide's block */
 				g_debug ("cria_slide_show_render_slide(): rendering from slide");
 
@@ -595,39 +570,46 @@ cria_slide_show_render_slide (CriaSlideShow *self) {
 						self->priv->group,
 						gnome_canvas_text_get_type (),
 						"anchor", gtk_anchor,
-					//	"clip", TRUE,
-					//	"clip-height", cria_layout_block_get_height (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
-					//	"clip-width", cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
+						/* "clip", TRUE,
+						"clip-height", cria_layout_block_get_height (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
+						"clip-width", cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width, */
 						"family", cria_layout_block_get_font_family (cria_layout_get_block (layout, *iterator)),
 						"justification", gtk_align,
 						"markup", cria_slide_block_get_processed_content (cria_slide_get_block (slide, *iterator)),
 						"size-points", font_size,
 						"size-set", TRUE,
 #warning 4 assertions that unit is percent
-						// TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length)
+						/* TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length) */
 						"x", xpos,
 						"y", ypos,
 						NULL
 						);
-			}
-			else
-			{
+			} else {
 				/* 2.2.b - render default block */
+				gchar const	* markup = NULL;
+				
 				g_debug ("cria_slide_show_render_slide(): rendering from layout");
+				if (cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator))==_("the block has no content")) {
+					markup = "";
+				} else {
+					markup = cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator));
+				}
+
+				g_message("Markup is:\n%s", markup);
 
 				gnome_canvas_item_new (
 						self->priv->group,
 						gnome_canvas_text_get_type (),
 						"anchor", gtk_anchor,
 						"clip", TRUE,
-						"clip-height", cria_layout_block_get_height (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
-						"clip-width", cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
+						"clip-height", cria_layout_block_get_height (cria_layout_get_block (layout, *iterator)) / 100 * cria_slide_get_display_height(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
+						"clip-width", cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
 						"family", cria_layout_block_get_font_family (cria_layout_get_block (layout, *iterator)),
 						"justification", gtk_align,
 						"size-points", font_size,
 						"size-set", TRUE,
 						"text", (cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator))==_("the block has no content"))?"":cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator)),
-						// TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length)
+						/* TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length) */
 						"x", xpos,
 						"y", ypos,
 						NULL
@@ -636,18 +618,16 @@ cria_slide_show_render_slide (CriaSlideShow *self) {
 		}
 
 		/* done */
-	}
-	else
-	{
+	} else {
 		/* render slide background */
 		gnome_canvas_item_new (
 				self->priv->group,
 				gnome_canvas_rect_get_type (),
 				"x1", (gdouble) 0.,
 				"y1", (gdouble) 0.,
-				// TODO update this to reflect slide size instead of screen size
-				"x2", (gdouble) CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
-				"y2", (gdouble) CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
+				/* TODO update this to reflect slide size instead of screen size */
+				"x2", (gdouble) cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
+				"y2", (gdouble) cria_slide_get_display_height(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()),
 				"fill-color", "darkslategray",
 				NULL);
 
@@ -659,9 +639,9 @@ cria_slide_show_render_slide (CriaSlideShow *self) {
 				"anchor", GTK_ANCHOR_CENTER,
 				"text", title,
 				"fill-color", "white",
-				// TODO update this to reflect slide instead of screen size
-				"x", (gdouble) (CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width / 2),
-				"y", (gdouble) (CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height / 2),
+				/* TODO update this to reflect slide instead of screen size */
+				"x", (gdouble) (cria_slide_get_display_width(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()) / 2),
+				"y", (gdouble) (cria_slide_get_display_height(cria_presentation_get_slide(self->presentation, self->slide), gdk_screen_get_default()) / 2),
 				NULL);
 		g_free (title);
 	}
@@ -727,7 +707,7 @@ cria_slide_show_set_presentation (
 
 	g_object_notify (G_OBJECT (self), "presentation");
 
-	g_debug ("cria_slide_show_set_presentation(%i): set presentation 0x%x", __LINE__, (guint)self->presentation);
+	g_debug ("cria_slide_show_set_presentation(%i): set presentation 0x%x", __LINE__, (uintptr_t)self->presentation);
 	g_debug ("cria_slide_show_set_presentation(%i): end", __LINE__);
 }
 
