@@ -27,6 +27,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 
 #include <gnome-canvas-helpers.h>
 
@@ -37,6 +38,8 @@
 
 #define SLIDE_VIEW_PADDING	12
 #define SLIDE_VIEW_SHADOW_OFFSET 6
+#define SLIDE_VIEW_ZOOM_DEFAULT 0.73
+#warning "FIXME: Auto zoom on default"
 
 enum {
 	PROP_0,
@@ -53,8 +56,8 @@ enum {
 
 struct _CriaSlideViewPriv {
 	GtkWidget	* canvas;
-	GnomeCanvasGroup* top_group;
-	GnomeCanvasGroup* group;
+	GnomeCanvasGroup* top_group,
+			* group;
 	GnomeCanvasItem	* shadow,
 			* border;
 	CriaSlide	* slide;
@@ -71,35 +74,19 @@ static	void	cria_slide_view_set_property           (GObject		* object,
 						        guint		  prop_id,
 						        const	GValue	* value,
 						        GParamSpec	* param_spec);
-static	void	cria_slide_view_slide_changed          (CriaSlideView	* template,
+static	void	cria_slide_view_slide_changed          (CriaSlideView	* self,
 						        gpointer	  data);
 static void	cria_slide_view_zoom_changed	       (CriaSlideView	* self,
 							gpointer	  data);
 
-static gdouble get_slide_width(void) {
-	gdouble	  screen_width = gdk_screen_get_width(gdk_screen_get_default()),
-		  screen_height= gdk_screen_get_height(gdk_screen_get_default());
-
-	if ((screen_width/screen_height) >= (4.0/3.0)) {
-		/* screen is too wide */
-		return screen_height*4.0/3.0;
-	} else {
-		/* screen is too high */
-		return screen_width;
-	}
+static gdouble
+get_slide_width(CriaSlide* slide) {
+	return cria_slide_get_display_width(slide, gdk_screen_get_default());
 }
 
-static gdouble get_slide_height(void) {
-	gdouble   screen_width = gdk_screen_get_width(gdk_screen_get_default()),
-		  screen_height= gdk_screen_get_height(gdk_screen_get_default());
-
-	if ((screen_width/screen_height) >= (4.0/3.0)) {
-		/* screen is too wide */
-		return screen_height;
-	} else {
-		/* screen is too high */
-		return screen_width*3.0/4.0;
-	}
+static gdouble
+get_slide_height(CriaSlide* slide) {
+	return cria_slide_get_display_height(slide, gdk_screen_get_default());
 }
 
 static	guint	cria_slide_view_signals[N_SIGNALS] = { 0 };
@@ -114,67 +101,52 @@ cria_slide_view_class_init (CriaSlideViewClass* cria_slide_view_class) {
 	cria_slide_view_class->slide_changed = cria_slide_view_slide_changed;
 	cria_slide_view_class->zoom_changed = cria_slide_view_zoom_changed;
 
-	cria_slide_view_signals[SIGNAL_SLIDE_CHANGED] = g_signal_new (
-			"slide-changed",
-			CRIA_TYPE_SLIDE_VIEW,
-			G_SIGNAL_RUN_LAST,
-			G_STRUCT_OFFSET (
-				CriaSlideViewClass,
-				slide_changed),
-			NULL,
-			NULL,
-			g_cclosure_marshal_VOID__VOID,
-			G_TYPE_NONE,
-			0);
-	cria_slide_view_signals[SIGNAL_ZOOM_CHANGED] = g_signal_new (
-			"zoom-changed",
-			CRIA_TYPE_SLIDE_VIEW,
-			G_SIGNAL_RUN_LAST,
-			G_STRUCT_OFFSET (
-				CriaSlideViewClass,
-				zoom_changed),
-			NULL,
-			NULL,
-			g_cclosure_marshal_VOID__VOID,
-			G_TYPE_NONE,
-			0);
+	cria_slide_view_signals[SIGNAL_SLIDE_CHANGED] = g_signal_new("slide-changed",
+								     CRIA_TYPE_SLIDE_VIEW,
+								     G_SIGNAL_RUN_LAST,
+								     G_STRUCT_OFFSET(CriaSlideViewClass, slide_changed),
+								     NULL,
+								     NULL,
+								     g_cclosure_marshal_VOID__VOID,
+								     G_TYPE_NONE,
+								     0);
+	cria_slide_view_signals[SIGNAL_ZOOM_CHANGED] = g_signal_new("zoom-changed",
+								    CRIA_TYPE_SLIDE_VIEW,
+								    G_SIGNAL_RUN_LAST,
+								    G_STRUCT_OFFSET(CriaSlideViewClass, zoom_changed),
+								    NULL,
+								    NULL,
+								    g_cclosure_marshal_VOID__VOID,
+								    G_TYPE_NONE,
+								    0);
 
 	/* setting up property system */
 	g_object_class->set_property = cria_slide_view_set_property;
 	g_object_class->get_property = cria_slide_view_get_property;
 
-	g_object_class_install_property (
-			g_object_class,
-			PROP_SLIDE,
-			g_param_spec_object (
-				"slide",
-				"Slide",
-				"The slide that's currently displayed in this view",
-				CRIA_TYPE_SLIDE,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_ZOOM,
-			g_param_spec_double (
-				"zoom",
-				"Zoom",
-				"Defines the zoom factor that should be applied to display the slide",
-				0.01,
-				G_MAXDOUBLE,
-				0.73, // FIXME this is a value that works well on my machine
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
-	g_object_class_install_property (
-			g_object_class,
-			PROP_ZOOM_AUTO,
-			g_param_spec_boolean (
-				"zoom-auto",
-				"Automatic zoom",
-				"Defines whether the slide view changes the zoom factor on resizing",
-				FALSE,
-				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
-			);
+	g_object_class_install_property(g_object_class,
+					PROP_SLIDE,
+					g_param_spec_object("slide",
+							    "Slide",
+							    "The slide that's currently displayed in this view",
+							    CRIA_TYPE_SLIDE,
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_ZOOM,
+					g_param_spec_double("zoom",
+							    "Zoom",
+							    "Defines the zoom factor that should be applied to display the slide",
+							    0.01,
+							    G_MAXDOUBLE,
+							    SLIDE_VIEW_ZOOM_DEFAULT,
+							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property(g_object_class,
+					PROP_ZOOM_AUTO,
+					g_param_spec_boolean("zoom-auto",
+							     "Automatic zoom",
+							     "Defines whether the slide view changes the zoom factor on resizing",
+							     FALSE,
+							     G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
 CriaSlide*
@@ -250,22 +222,23 @@ static void
 cria_slide_view_init(CriaSlideView   * self) {
 	/* prepare private data */
 	self->priv = g_new0(CriaSlideViewPriv,1);
+	self->priv->zoom = SLIDE_VIEW_ZOOM_DEFAULT;
+
+	/* set up the scrolled window */
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(self), GTK_SHADOW_IN);
 
 	/* prepare the canvas */
-	self->priv->canvas = gnome_canvas_new_aa();
-	gnome_canvas_set_scroll_region(
-			GNOME_CANVAS(self->priv->canvas),
-			0.0 - SLIDE_VIEW_PADDING,
-			0.0 - SLIDE_VIEW_PADDING,
-			get_slide_width() + SLIDE_VIEW_SHADOW_OFFSET + SLIDE_VIEW_PADDING,
-			get_slide_height() + SLIDE_VIEW_SHADOW_OFFSET + SLIDE_VIEW_PADDING);
-	gnome_canvas_set_center_scroll_region(
-			GNOME_CANVAS(self->priv->canvas),
-			TRUE);
+	self->priv->canvas	= gnome_canvas_new_aa();
+	gnome_canvas_set_scroll_region(GNOME_CANVAS(self->priv->canvas),
+				       0.0 - SLIDE_VIEW_PADDING,
+				       0.0 - SLIDE_VIEW_PADDING,
+				       get_slide_width(self->priv->slide) + SLIDE_VIEW_SHADOW_OFFSET + SLIDE_VIEW_PADDING,
+				       get_slide_height(self->priv->slide) + SLIDE_VIEW_SHADOW_OFFSET + SLIDE_VIEW_PADDING);
+	gnome_canvas_set_center_scroll_region(GNOME_CANVAS(self->priv->canvas), TRUE);
 
 	/* prepare the canvas groups */
 	self->priv->top_group = GNOME_CANVAS_GROUP(gnome_canvas_item_new(gnome_canvas_root(GNOME_CANVAS(self->priv->canvas)),
-						   			 gnome_canvas_group_get_type(),
+									 gnome_canvas_group_get_type(),
 									 "x", 0.0,
 									 "y", 0.0,
 									 NULL));
@@ -274,19 +247,20 @@ cria_slide_view_init(CriaSlideView   * self) {
 								     "x", 0.0,
 								     "y", 0.0,
 								     NULL));
-	gnome_canvas_item_show(GNOME_CANVAS_ITEM(self->priv->group));
 	gnome_canvas_item_show(GNOME_CANVAS_ITEM(self->priv->top_group));
+	gnome_canvas_item_show(GNOME_CANVAS_ITEM(self->priv->group));
 
 	/* add the shadow */
 	self->priv->shadow = gnome_canvas_item_new(self->priv->top_group,
 						   gnome_canvas_rect_get_type(),
-						   "fill-color", "darkgray",
+						   "fill-color", "gray",
 						   "x1", 0.0 + SLIDE_VIEW_SHADOW_OFFSET,
-						   "x2", get_slide_width() + SLIDE_VIEW_SHADOW_OFFSET,
 						   "y1", 0.0 + SLIDE_VIEW_SHADOW_OFFSET,
-						   "y2", get_slide_height() + SLIDE_VIEW_SHADOW_OFFSET,
+						   "x2", 0.0 + SLIDE_VIEW_SHADOW_OFFSET + get_slide_width(self->priv->slide),
+						   "y2", 0.0 + SLIDE_VIEW_SHADOW_OFFSET + get_slide_height(self->priv->slide),
 						   NULL);
 	gnome_canvas_item_show(self->priv->shadow);
+	gnome_canvas_item_lower_to_bottom(self->priv->shadow);
 
 	/* add the slide border */
 	self->priv->border = gnome_canvas_item_new(self->priv->top_group,
@@ -294,12 +268,15 @@ cria_slide_view_init(CriaSlideView   * self) {
 						   "outline-color", "black",
 						   "width-pixels", 1,
 						   "x1", 0.0,
-						   "x2", get_slide_width(),
 						   "y1", 0.0,
-						   "y2", get_slide_height(),
+						   "x2", 0.0 + get_slide_width(self->priv->slide),
+						   "y2", 0.0 + get_slide_height(self->priv->slide),
 						   NULL);
-	gnome_canvas_item_show(self->priv->shadow);
+	gnome_canvas_item_show(self->priv->border);
+	gnome_canvas_item_raise_to_top(self->priv->border);
+
 	gtk_widget_show(self->priv->canvas);
+
 	gtk_scrolled_window_set_hadjustment(GTK_SCROLLED_WINDOW(self), gtk_layout_get_hadjustment(GTK_LAYOUT(self->priv->canvas)));
 	gtk_scrolled_window_set_vadjustment(GTK_SCROLLED_WINDOW(self), gtk_layout_get_vadjustment(GTK_LAYOUT(self->priv->canvas)));
 	gtk_container_add(GTK_CONTAINER(self), self->priv->canvas);
@@ -327,8 +304,7 @@ cria_slide_view_set_slide (CriaSlideView* self, CriaSlide* slide) {
 		self->priv->slide = NULL;
 	}
 
-	g_signal_emit_by_name(self,
-			      "slide-changed");
+	g_signal_emit_by_name(self, "slide-changed");
 	g_object_notify (G_OBJECT (self), "slide");
 
 	g_debug("cria_slide_view_set_slide(): end");
@@ -373,7 +349,6 @@ cria_slide_view_set_zoom(CriaSlideView* self, gdouble zoom) {
 	g_assert(self->priv != NULL);
 	g_assert(self->priv->canvas != NULL);
 	g_assert(GNOME_IS_CANVAS(self->priv->canvas));
-	g_assert(zoom > GNOME_CANVAS_EPSILON);
 
 	if(self->priv->zoom != zoom) {
 		self->priv->zoom = zoom;
@@ -395,7 +370,7 @@ cria_slide_view_set_zoom_auto(CriaSlideView* self, gboolean zoom_auto) {
 
 		g_object_notify(G_OBJECT(self), "zoom-auto");
 		/* FIXME think whether we really need this */
-		//g_signal_emit_by_name(G_OBJECT(self), "zoom-auto-toggle");
+		/* g_signal_emit_by_name(G_OBJECT(self), "zoom-auto-toggle"); */
 	}
 }
 
@@ -410,15 +385,13 @@ cria_slide_view_clear_canvas(CriaSlideView* self) {
 	g_assert(GNOME_IS_CANVAS_ITEM(self->priv->shadow));
 	g_assert(self->priv->border != NULL);
 	g_assert(GNOME_IS_CANVAS_ITEM(self->priv->border));
-
 	gnome_canvas_item_hide(GNOME_CANVAS_ITEM(self->priv->group));
 	gtk_object_destroy(GTK_OBJECT(self->priv->group));
 	self->priv->group = NULL;
 
-	self->priv->group = GNOME_CANVAS_GROUP(gnome_canvas_item_new(
-				                  self->priv->top_group,
-						  gnome_canvas_group_get_type(),
-						  NULL));
+	self->priv->group = GNOME_CANVAS_GROUP(gnome_canvas_item_new(self->priv->top_group,
+								     gnome_canvas_group_get_type(),
+								     NULL));
 	/* move the slide border over the group and the shadow below it */
 	gnome_canvas_item_raise_to_top(self->priv->border);
 	gnome_canvas_item_lower_to_bottom(self->priv->shadow);
@@ -434,15 +407,17 @@ cria_slide_view_render_background_default(CriaSlideView* self) {
 	g_assert(self->priv->group != NULL);
 	g_assert(GNOME_IS_CANVAS_GROUP(self->priv->group));
 
-	c_item = gnome_canvas_item_new (self->priv->group,
-					gnome_canvas_rect_get_type(),
-					"fill-color", "white",
-					"x1", 0.0,
-					"x2", get_slide_width(),
-					"y1", 0.0,
-					"y2", get_slide_height(),
-					NULL);
+	g_debug("cria_slide_view_render_background_default(): before adding the item");
+	c_item = gnome_canvas_item_new(self->priv->group,
+				       gnome_canvas_rect_get_type(),
+				       "fill-color", "white",
+				       "x1", 0.0,
+				       "y1", 0.0,
+				       "x2", 0.0 + get_slide_width(self->priv->slide),
+				       "y2", 0.0 + get_slide_height(self->priv->slide),
+				       NULL);
 	gnome_canvas_item_show(c_item);
+	g_debug("cria_slide_view_render_background_default(): after adding the item");
 }
 
 static void
@@ -458,23 +433,26 @@ cria_slide_view_render_background_pixmap(CriaSlideView* self) {
 	g_assert(CRIA_IS_SLIDE(slide));
 	g_assert(CRIA_IS_LAYOUT(layout));
 
-	if (TRUE) { // is_stretched
+	if (TRUE) { /* is_stretched */
 		GnomeCanvasItem	* c_item;
 		c_item = gnome_canvas_item_new (
 				self->priv->group,
 				gnome_canvas_pixbuf_get_type (),
 				"x", 0.0,
 				"y", 0.0,
-				"height", get_slide_height(),
+				"height", get_slide_height(self->priv->slide),
 				"height-set", TRUE,
 				"pixbuf", cria_layout_get_background (layout),
-				"width", get_slide_width(),
+				"width", get_slide_width(self->priv->slide),
 				"width-set", TRUE,
 				NULL);
 		gnome_canvas_item_show(c_item);
-	} else if (FALSE) { // is scaled
-	} else if (FALSE) { // is tiled
-	} else if (FALSE) { // is aligned
+	} else if (FALSE) { /* is scaled */
+#warning "SlideView::renderBackground(): FIXME implement streched background"
+	} else if (FALSE) { /* is tiled */
+#warning "SlideView::renderBackground(): FIXME implement tiled background"
+	} else if (FALSE) { /* is aligned */
+#warning "SlideView::renderBackground(): FIXME implement aligned background"
 	} else {
 		g_assert_not_reached();
 	}
@@ -488,8 +466,6 @@ cria_slide_view_render_background(CriaSlideView* self) {
 	g_assert(self != NULL);
 	g_assert(CRIA_IS_SLIDE_VIEW(self));
 	g_assert(self->priv != NULL);
-	g_assert(self->priv->group != NULL);
-	g_assert(GNOME_IS_CANVAS_GROUP(self->priv->group));
 
 	slide = cria_slide_view_get_slide(self);
 	g_assert(slide == NULL || CRIA_IS_SLIDE(slide));
@@ -513,7 +489,7 @@ cria_slide_view_render_background(CriaSlideView* self) {
 	if (GDK_IS_PIXBUF(cria_layout_get_background(layout))) {
 		/* render a pixbuf background */
 		cria_slide_view_render_background_pixmap(self);
-	} else if (FALSE) { // BACKGROUND_IS_COLOR
+	} else if (FALSE) { /* BACKGROUND_IS_COLOR */
 		/* render a colored background */
 	} else if (FALSE) {
 		/* render a gradient background */
@@ -545,10 +521,10 @@ cria_slide_view_render_block(CriaSlideView* self, CriaSlide* slide, gchar const*
 	g_assert(layout != NULL);
 	g_assert(CRIA_IS_LAYOUT(layout));
 
-	x = cria_layout_block_get_pos_x (cria_layout_get_block (layout, blockname)) / 100 * get_slide_width();
-	y = cria_layout_block_get_pos_y (cria_layout_get_block (layout, blockname)) / 100 * get_slide_height();
-	width = cria_layout_block_get_width (cria_layout_get_block (layout, blockname)) / 100 * get_slide_width();
-	height = cria_layout_block_get_height(cria_layout_get_block (layout, blockname)) / 100 * get_slide_height();
+	x = cria_layout_block_get_pos_x (cria_layout_get_block (layout, blockname)) / 100 * get_slide_width(self->priv->slide);
+	y = cria_layout_block_get_pos_y (cria_layout_get_block (layout, blockname)) / 100 * get_slide_height(self->priv->slide);
+	width = cria_layout_block_get_width (cria_layout_get_block (layout, blockname)) / 100 * get_slide_width(self->priv->slide);
+	height = cria_layout_block_get_height(cria_layout_get_block (layout, blockname)) / 100 * get_slide_height(self->priv->slide);
 
 	font_size = cria_layout_block_get_font_size (cria_layout_get_block (layout, blockname));
 
@@ -576,7 +552,7 @@ cria_slide_view_render_block(CriaSlideView* self, CriaSlide* slide, gchar const*
 		c_item = gnome_canvas_item_new (self->priv->group,
 						gnome_canvas_text_get_type (),
 						"anchor", anchor,
-						//"clip", TRUE,
+						/*"clip", TRUE, */
 						"clip-height", height,
 						"clip-width", width,
 						"family", cria_layout_block_get_font_family (cria_layout_get_block (layout, blockname)),
@@ -584,7 +560,7 @@ cria_slide_view_render_block(CriaSlideView* self, CriaSlide* slide, gchar const*
 						"justification", justification,
 						"size-set", TRUE,
 						"markup", cria_slide_block_get_processed_content (cria_slide_get_block (slide, blockname)),
-						// TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length)
+						/* TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length) */
 						"x", x,
 						"y", y,
 						NULL);
@@ -597,11 +573,10 @@ cria_slide_view_render_block(CriaSlideView* self, CriaSlide* slide, gchar const*
 		if (strcmp(text, _("the block has no content")) == 0) {
 			text = "";
 		}
-
 		c_item = gnome_canvas_item_new (self->priv->group,
 						gnome_canvas_text_get_type (),
 						"anchor", anchor,
-//						"clip", TRUE,
+						/* "clip", TRUE, */
 						"clip-height", height,
 						"clip-width", width,
 						"family", cria_layout_block_get_font_family (cria_layout_get_block (layout, blockname)),
@@ -609,9 +584,9 @@ cria_slide_view_render_block(CriaSlideView* self, CriaSlide* slide, gchar const*
 						"justification", justification,
 						"size-set", TRUE,
 						"text", text,
-//						"weight", PANGO_WEIGHT_BOLD,
-//						"weight-set", TRUE,
-						// TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length)
+						/*"weight", PANGO_WEIGHT_BOLD,
+						"weight-set", TRUE,*/
+						/* TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length) */
 						"x", x,
 						"y", y,
 						NULL);
