@@ -41,6 +41,10 @@ void		cria_slide_add_block	       (CriaSlide	* self,
 						CriaSlideBlock	* block);
 CriaSlideBlock*	cria_slide_get_block	       (CriaSlide	* self,
 						gchar const	* block);
+gdouble		cria_slide_get_display_height  (CriaSlide	* self,
+						GdkScreen	* screen);
+gdouble		cria_slide_get_display_width   (CriaSlide	* self,
+						GdkScreen	* screen);
 GType		cria_slide_get_type	       (void);
 CriaLayout*	cria_slide_get_layout	       (CriaSlide	* self);
 CriaTheme*	cria_slide_get_theme	       (CriaSlide	* self);
